Generate a Stics workspace from SMS data, for evaluation and calibration.

gen_workspace_from_sms(
  sms_path,
  stics_path,
  output_dir,
  usms_files = NULL,
  parallel = FALSE,
  cores = NA
)

Arguments

sms_path

path to the SMS repository

stics_path

path to Stics repository

output_dir

path to the Stics workspace to generate

usms_files

character vector of one or more paths to text files listing the USMs (one per line) to generate. If NULL (default), all evaluation and calibration USMs are generated.

parallel

Boolean. Is the computation to be done in parallel ?

cores

Number of cores to use for parallel computation

Value

NULL (invisibly)