Get statistics from the evaluation repository

get_stats(data_dir, species, collect = FALSE)

Arguments

data_dir

Path to the evaluation repository

species

Character string specifying the species to retrieve statistics for

collect

If TRUE, returns a data.frame. If FALSE, returns an Arrow dataset

Value

A data.frame or Arrow dataset with statistics for the given species, or NULL if no stats file is found