Run the evaluation workflow
Evaluation$new()Create an evaluation workflow
Evaluation$new(
config,
workspace = NULL,
backend = NULL,
logger = default_logger,
summary_class = EvaluationSummary
)configthe configuration of the evaluation workflow
workspacean object of class EvalWorkspace to access the
evaluation data (default: EvalWorkspace$new(config$eval_workspace))
backendan object of class ParallelBackend to run parallel
computations (default:
ParallelBackend$new(config$parallel, config$cores))
loggera logger object with info, debug, warn and error
methods (default: uses the logger package)
summary_classa class to build the summary of the evaluation
(default: EvaluationSummary)
Evaluation$run()Run the evaluation workflow This function orchestrates the full evaluation workflow based on a given configuration object. It initializes logging, optionally prepares the evaluation workspace, runs the evaluation globally and then for all species, and displays summary information.
if (FALSE) { # \dontrun{
config <- Configuration$new(
stics_exe = "/path/to/stics",
eval_workspace = "workspace/",
metadata_file = "metadata.csv"
)
Evaluation$new(config)$run()
} # }