This function exports different evaluation metrics from the evaluation workspace into CSV files. It retrieves data from the workspace and writes the following datasets when available:
export_stats_to_csv(config)NULL. This function is called for its side effects (writing files).
Species statistics (species_stats.csv)
Global statistics (global_stats.csv)
RMSE per USM (RMSE_per_usm.csv)
List of deteriorated USMs (Deteriorated_USM.csv)
The data are retrieved from the evaluation workspace using dedicated helper
functions. Files are written safely using safe_write_csv().
The function:
Validates the configuration for export.
Creates the output directory if needed.
Exports species statistics if available.
Exports global statistics if available.
Exports RMSE per USM if available.
Exports deteriorated USM information if available.
if (FALSE) { # \dontrun{
config <- make_config(
output_dir = "results/"
)
export_stats_to_csv(config)
} # }