This function exports different evaluation metrics for each species found in the evaluation workspace into CSV files. For every species, it creates an output directory (if needed) and writes the following datasets when available:

export_stats_to_csv(config)

Arguments

config

List. Configuration object created by make_config(), containing all parameters required for the export.

Value

NULL. This function is called for its side effects (writing files).

Details

  • Global statistics (Criteres_stats.csv)

  • RMSE per USM (RMSE_per_usm.csv)

  • List of deteriorated USMs (Deteriorated_USM.csv)

The data are retrieved from the evaluation workspace using dedicated helper functions. Files are written safely using safe_write_csv().

For each species:

  • Creates a species-specific output directory.

  • Exports statistics if available.

  • Exports RMSE per USM if available.

  • Exports deteriorated USM information if available.

Examples

if (FALSE) { # \dontrun{
config <- make_config(
 output_dir = "results/"
)
export_stats_to_csv(config)
} # }