This function generates diagnostic plots for each species found in the evaluation workspace. It produces comparison plots and, when possible, scatter plots highlighting deteriorated variables based on a given threshold.
gen_plots(config)List. Configuration object created by make_config(),
containing all parameters required for the plots generation
NULL. This function is called for its side effects (writing plot files).
For each species, the function:
Retrieves comparison data between simulation and observation.
Generates comparison plots.
Identifies deteriorated variables using a threshold percentage.
Optionally generates scatter plots if reference simulation data are available.
Scatter plots are only generated when both reference simulation data and deteriorated variables are available.
For each species:
Creates a species-specific output directory.
Generates comparison plots using gen_comparison_plot().
Identifies critical and warning variables using the given percentage.
Generates scatter plots using gen_scatter_plot() if reference data
and deteriorated variables are available.
if (FALSE) { # \dontrun{
config <- make_config(
output_dir = "results/",
reference_workspace = "ref_dir/"
)
gen_plots(config)
} # }