R/gen_workspace_from_sms.R
gen_workspace_from_sms.RdGenerate a Stics workspace from SMS data, for evaluation and calibration.
gen_workspace_from_sms(
sms_path,
stics_path,
output_dir,
usms_files = NULL,
parallel = FALSE,
cores = NA
)path to the SMS repository
path to Stics repository
path to the Stics workspace to generate
character vector of one or more paths to text files listing the USMs (one per line) to generate. If NULL (default), all evaluation and calibration USMs are generated.
Boolean. Is the computation to be done in parallel ?
Number of cores to use for parallel computation
NULL (invisibly)